' ###############################################################################
' # Licensed Materials - Property of IBM
' # 5724-T40 IBM License Metric Tool
' # 5724-S94 IBM Tivoli Asset Discovery for Distributed
' #
' # (C) Copyright IBM Corp. 2004, 2011.  All Rights Reserved.
' #
' # US Government Users Restricted Rights - Use, duplication or
' # disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
' ###############################################################################

' Force all variables to be declared
option explicit

dim currentArg, argCount, force, zerog_registry_file, fix_file, fso

set fso = CreateObject("Scripting.FileSystemObject")
currentArg=0
argCount = WScript.arguments.count
do while currentArg < argCount
	if (currentArg = 0) then
		dir_path = WScript.arguments(currentArg)
	elseif (currentArg = 1) then
		force = WScript.arguments(currentArg)
	end if
	currentArg = currentArg + 1
loop

dim IF_version, current_version, IF_marker_file, db_script_filename, dir_path, backup_dir, jars
dim selfupdate, selfupdate_data, selfupdate_properties, if_update_agents, if_update_UI_classes, UI_classes

' ***************************************************************
' CONFIGURATION SECTION
' ***************************************************************
IF_version = "IF2"
current_version = "7.2.2.1"
IF_marker_file = "7221_IF2.dat"
db_script_filename = "migrate_7.2.2.12.sql"
if_update_agents = False
if_update_UI_classes = False

backup_dir = "7.2.2.12_backup_" & Year(Date) & Month(Date) & Day(Date) & "_" & Hour(Time) & Minute(Time)
jars = "jars"
selfupdate = "selfupdate"
selfupdate_data = "data"
selfupdate_properties = "properties"
UI_classes = "UI_classes" 'folder name in backup for UI classes
zerog_registry_file = "C:\Program Files\Zero G Registry\.com.zerog.registry.xml"
' ***************************************************************

'Checking whether .com.zerog.registry.xml file exists if force was not used
if force <> "force" then
	if fso.fileexists(zerog_registry_file) then 
		WScript.Echo "SUCCESS: Install Anywhere registry file found."
	else
		zerog_registry_file = "C:\Program Files (x86)\Zero G Registry\.com.zerog.registry.xml"
		if fso.fileexists(zerog_registry_file) then 
			WScript.Echo "SUCCESS: Install Anywhere registry file found."
		else
			WScript.Echo "Error: Required Install Anywhere registry file '" & zerog_registry_file & "' is missing."
			showUsageAndQuit		
		end if
	end if
end if


'Checking if the LMT directory was provided, if not pulls it from the registry file
Dim oFile, sText, ifFound, myRegExp, myMatches, myMatch
Set myRegExp = New RegExp
myRegExp.IgnoreCase = False
myRegExp.Global = True
myRegExp.Pattern = "^.*<product.*(IBM Tivoli Asset Discovery for Distributed|IBM License Metric Tool).*$"
ifFound = False
if dir_path = "" then
	Set oFile = fso.OpenTextFile(zerog_registry_file, 1)
	Do While (ifFound = False and Not oFile.AtEndOfStream)
		sText = oFile.ReadLine
		If Trim(sText) <> "" Then
			Set myMatches = myRegExp.Execute(sText)
			For Each myMatch in myMatches				
				ifFound = True
			Next
		end if
	Loop
	oFile.Close
	if ifFound then
		myRegExp.Pattern = "^.*location="""
		sText = myRegExp.Replace(sText, "")
		myRegExp.Pattern = """.*"
		sText = myRegExp.Replace(sText, "")
		dir_path = sText
		WScript.Echo "ILMT/TAD4D install directory read from reqistry file: " & dir_path
	else
		WScript.Echo "Error: There is no ILMT/TAD4D entry in Install Anywhere registy file"
		showUsageAndQuit
	end if
else
	WScript.Echo "Using ILMT/TAD4D install location: " & dir_path
end if

'Checking if the LMT directory exists
if not fso.folderexists(dir_path) then
	WScript.Echo "Error: The ILMT/TAD4D directory (" & dir_path & ") does not exists."
	showUsageAndQuit
else
	backup_dir = dir_path & "\" & backup_dir
end if

'Checking the software version in registry file (if the force was not used)
if force <> "force" then
	myRegExp.Pattern = "^.*<product.*(IBM Tivoli Asset Discovery for Distributed|IBM License Metric Tool).*$"
	ifFound = False
	set oFile = fso.OpenTextFile(zerog_registry_file, 1)
	Do While (ifFound = False and Not oFile.AtEndOfStream)
		sText = oFile.ReadLine
		If Trim(sText) <> "" Then
			Set myMatches = myRegExp.Execute(sText)
			For Each myMatch in myMatches				
				ifFound = True
			Next
		end if
	Loop
	oFile.Close	
	myRegExp.Pattern = "^.*version="""
	sText = myRegExp.Replace(sText, "")
	myRegExp.Pattern = """.*"
	sText = myRegExp.Replace(sText, "")
	WScript.Echo "Currently installed product version: " & 	sText
	if sText <> current_version then
		WScript.Echo "Error: Unsupported product version (" & sText &"), it needs to be ILMT/TAD4D " & current_version
		WScript.quit		
	end if
else
	WScript.Echo "Force option used - not checking the currently installed product version."
end if

'if the Interim fix was already installed
fix_file = dir_path & "\" & IF_marker_file
if fso.fileexists(fix_file) and force <> "force" then 
	WScript.Echo "Error: Interim Fix " & current_version & " " & IF_version & " is already installed."
	WScript.quit
end if

'Checking whether it is ILMT or TAD4D installation
dim lmt_war_path, tad4d_war_path, admin__libdir, msghandler_libdir, selfupdate_properties_path, selfupdate_data_path, UI_classes__dir
lmt_war_path = dir_path & "\eWAS\systemApps\isclite.ear\lmt_admin.war"
tad4d_war_path = dir_path & "\eWAS\systemApps\isclite.ear\tad4d_admin.war"
admin__libdir = dir_path & "\eWAS\systemApps\isclite.ear\lmt_admin.war\WEB-INF\lib\"
UI_classes__dir = dir_path & "\eWAS\systemApps\isclite.ear\lmt_admin.war\WEB-INF\classes\com\ibm\license\mgmt\ui"
msghandler_libdir = dir_path & "\eWAS\profiles\AppSrv01\installedApps\cell1\LMT-TAD4D_Agent_message_handler.ear\com.ibm.license.mgmt.msghandler.web.war\WEB-INF\lib\"
selfupdate_properties_path = dir_path & "\eWAS\profiles\AppSrv01\installedApps\cell1\LMT-TAD4D_Agent_message_handler.ear\com.ibm.license.mgmt.msghandler.web.war\WEB-INF\conf\selfupdate\"
selfupdate_data_path = dir_path & "\eWAS\profiles\AppSrv01\installedApps\cell1\LMT-TAD4D_Agent_message_handler.ear\com.ibm.license.mgmt.msghandler.web.war\webdoc\agent\selfupdate\"

if fso.folderexists(lmt_war_path) then
	WScript.Echo "ILMT installation was found."
else
	if fso.folderexists(tad4d_war_path) then
		WScript.Echo "TAD4D installation was found."
		admin__libdir = dir_path & "\eWAS\systemApps\isclite.ear\tad4d_admin.war\WEB-INF\lib\"
		UI_classes__dir = dir_path & "\eWAS\systemApps\isclite.ear\tad4d_admin.war\WEB-INF\classes\com\ibm\license\mgmt\ui"
	else
		WScript.Echo "Error: Cannot locate the product directories, check whether the provided product install dir is correct."
		WScript.quit
	end if
end if

'Checking whether lib directories exists 
if not (fso.folderexists(admin__libdir) and fso.folderexists(msghandler_libdir)) then	
	WScript.Echo "Error: the msghandler or admin server lib directory cannot be located."
	WScript.quit
end if

if if_update_agents and not (fso.folderexists(selfupdate_properties_path) and fso.folderexists(selfupdate_data_path)) then
	WScript.Echo "Error: the agent self updates directories cannot be located."
	WScript.quit
end if

if if_update_UI_classes and not fso.folderexists(UI_classes__dir) then
	WScript.Echo "Error: the UI classes directories cannot be located."
	WScript.quit
end if

'Stopping the server
dim srvstop, ReturnCode, WshShell
srvstop = dir_path & "\cli\srvstop.bat"
if fso.fileexists(srvstop) then
	WScript.Echo "Stopping the server ..."
	Set WshShell = WScript.CreateObject("WScript.Shell")
	ReturnCode = WshShell.Run("""" & srvstop & """", 0, true)
	if ReturnCode = 0 then
		WScript.Echo "SUCCESS: server stopped successfully..."		
	elseif ReturnCode = -10 then
		WScript.Echo "SUCCESS: server was already stopped..."		
	else
		WScript.Echo "Error: Server could not be stopped. Stop the server manually and run the script again."
		WScript.quit
	end if
else 
	WScript.Echo "Error: Cannot find srvstop.bat script to stop the server."
	WScript.quit
end if



'BACKUP CREATE FOLDERS
WScript.Echo "Creating backup files in " & backup_dir & " directory"

if fso.folderexists(backup_dir) then
	fso.DeleteFolder backup_dir, True
end if

fso.CreateFolder(backup_dir)
fso.CreateFolder(backup_dir & "\" & jars)

if if_update_agents then
	fso.CreateFolder(backup_dir & "\" & selfupdate)
	fso.CreateFolder(backup_dir & "\" & selfupdate & "\" & selfupdate_data)
	fso.CreateFolder(backup_dir & "\" & selfupdate & "\" & selfupdate_properties)
end if

if if_update_UI_classes then
	fso.CreateFolder(backup_dir & "\" & UI_classes)
end if

'BACKUP COPY
fso.CopyFile admin__libdir & "com.ibm.license.mgmt.*.jar", backup_dir & "\" & jars, True
fso.CopyFile msghandler_libdir & "com.ibm.license.mgmt.msghandler.*.jar", backup_dir & "\" & jars, True

if if_update_agents then
	fso.CopyFile selfupdate_properties_path & "*", backup_dir & "\" & selfupdate & "\" & selfupdate_properties, True
	fso.CopyFile selfupdate_data_path & "*", backup_dir & "\" & selfupdate & "\" & selfupdate_data, True
end if

if if_update_UI_classes then
	fso.CopyFolder UI_classes__dir, backup_dir & "\" & UI_classes, True
end if

'INSTALLATION
WScript.Echo "Replacing the files"

fso.CopyFile jars & "\com.ibm.license.mgmt.admin.aggregation.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.admin.catalog.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.admin.inventory.builder.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.admin.periodictasks.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.admin.web.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.bl.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.catalog.importer.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.configmgr.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.core.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.dao.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.encryption.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.hwinfo.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.msgandtrace.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.srvfrontend.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.topologymgr.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.util.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.vmmanager.jar", admin__libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.ws.serialization.jar", admin__libdir, True

fso.CopyFile jars & "\com.ibm.license.mgmt.bl.jar", msghandler_libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.configmgr.jar", msghandler_libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.core.jar", msghandler_libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.dao.jar", msghandler_libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.encryption.jar", msghandler_libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.hwinfo.jar", msghandler_libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.msgandtrace.jar", msghandler_libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.msghandler.core.jar", msghandler_libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.msghandler.web.jar", msghandler_libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.srvfrontend.jar", msghandler_libdir, True
fso.CopyFile jars & "\com.ibm.license.mgmt.util.jar", msghandler_libdir, True

if if_update_agents then
	fso.DeleteFile selfupdate_data_path & "*", True
	fso.CopyFile selfupdate & "\" & selfupdate_data & "\*", selfupdate_data_path, True
	fso.CopyFile selfupdate & "\" & selfupdate_properties & "\*", selfupdate_properties_path, True
end if

if if_update_UI_classes then
	fso.CopyFolder UI_classes, UI_classes__dir, True
end if

'MARKER FILE
WScript.Echo "All files replaced"
WScript.Echo "Creating a " & current_version & " " & IF_version & " file."
dim objTextFile
set objTextFile = fso.CreateTextFile(fix_file, True)
objTextFile.Write(current_version & " " & IF_version)
objTextFile.Close()

WScript.Echo
WScript.Echo "Replacing files for ILMT/TAD4D " & current_version & " " & IF_version & " Interim Fix ended SUCCESSFULLY."
WScript.Echo "ILMT/TAD4D server is now stopped since additional, manual action is still needed."
WScript.Echo "Please go to the machine where TLMA DB is placed and run the SQL script " & db_script_filename
WScript.Echo "which comes with the Interim Fix. To do this execute the following DB2 command:"
WScript.Echo "                     db2 -vf " & db_script_filename & " -td%"
WScript.Echo "Once this task is completed, please start the ILMT/TAD4D server to finish Interim Fix application."

Sub showUsageAndQuit
    WScript.Echo "Use the InterimFix installer using the following params:"
	WScript.Echo "   install.bat [<ILMT|TAD4D-install-dir>] [force]"
	WScript.quit
End Sub